==> three-cover-1.0.5.tgz: package/src/index.tsx <==
import React, { useEffect, useRef, useState } from 'react';
import { Canvas, useFrame } from '@react-three/fiber';
import { useCursor, MeshReflectorMaterial, Image, Text, Environment } from '@react-three/drei';
import { useRoute, useLocation } from 'wouter';
import getUuid from 'uuid-by-string';
import THREE, { Color, Quaternion, Vector3 } from 'three';

const GOLDENRATIO = 1.61803398875;

const ThreeCover = (images: Array<any>) => {
    return (
        // @ts-ignore
        <Canvas gl={{ alpha: false }} dpr={[1, 1.5]} camera={{ fov: 70, position: [0, 2, 15] }}>
            <color attach="background" args={['#191920']} />
            <fog attach="fog" args={['#191920', 0, 15]} />
            <Environment preset="city" />
            <group position={[0, -0.5, 0]}>
                {
                    // @ts-ignore
                    <Frames images={images} />
                }
                <mesh rotation={[-Math.PI / 2, 0, 0]} position={[0, 0, 0]}>
                    <planeGeometry args={[50, 50]} />
                    {
                        // @ts-ignore
                        <MeshReflectorMaterial
                            blur={[300, 100]}
                            resolution={2048}
                            mixBlur={1}
                            mixStrength={40}
                            roughness={1}
                            depthScale={1.2}
                            minDepthThreshold={0.4}
                            maxDepthThreshold={1.4}
                            color="#050505"
                            metalness={0.5}
                        />
                    }
                </mesh>
            </group>
        </Canvas>
    );
};

function Frames(images: Array<any>, q: Quaternion = new THREE.Quaternion(), p: Vector3 = new THREE.Vector3()) {
    const ref = useRef();
    const clicked = useRef();
    const [, params] = useRoute('/item/:id');
    const [, setLocation] = useLocation();
    useEffect(() => {
        // @ts-ignore
        clicked.current = ref.current.getObjectByName(params?.id);
        if (clicked.current) {
            // @ts-ignore
            clicked.current.parent.updateWorldMatrix(true, true);
            // @ts-ignore
            clicked.current.parent.localToWorld(p.set(0, GOLDENRATIO / 2, 1.25));
            // @ts-ignore
            clicked.current.parent.getWorldQuaternion(q);
        } else {
            p.set(0, 0, 5.5);
            q.identity();
        }
    });
    useFrame((state) => {
        state.camera.position.lerp(p, 0.025);
        state.camera.quaternion.slerp(q, 0.025);
    });

    return (
        <group
            // @ts-ignore
            ref={ref}
            onClick={(e) => (
                e.stopPropagation(), setLocation(clicked.current === e.object ? '/' : '/item/' + e.object.name)
            )}
            onPointerMissed={() => setLocation('/')}
        >
            <Frame key={images[0]?.url} {...images[0]} />
        </group>
    );
}

function Frame(url: string, c: Color = new THREE.Color(), ...props: any) {
    const [hovered, hover] = useState(false);
    const [rnd] = useState(() => Math.random());
    const image = useRef();
    const frame = useRef();
    const name = getUuid(url.toString());
    useCursor(hovered);
    useFrame((state) => {
        // @ts-ignore
        image.current.material.zoom = 2 + Math.sin(rnd * 10000 + state.clock.elapsedTime / 3) / 2;
        // @ts-ignore
        image.current.scale.x = THREE.MathUtils.lerp(
            // @ts-ignore
            image.current.scale.x,
            0.85 * (hovered ? 0.85 : 1),
            0.1,
        );
        // @ts-ignore
        image.current.scale.y = THREE.MathUtils.lerp(
            // @ts-ignore
            image.current.scale.y,
            0.9 * (hovered ? 0.905 : 1),
            0.1,
        );
        // @ts-ignore
        frame.current.material.color.lerp(c.set(hovered ? 'orange' : 'white'), 0.1);
    });

    return (
        <group {...props}>
            <mesh
                name={name}
                onPointerOver={(e) => (e.stopPropagation(), hover(true))}
                onPointerOut={() => hover(false)}
                scale={[1, GOLDENRATIO, 0.05]}
                position={[0, GOLDENRATIO / 2, 0]}
            >
                <boxGeometry />
                <meshStandardMaterial
                    color="#151515"
                    metalness={0.5}
                    roughness={0.5}
                    envMapIntensity={2}
                />
                <mesh
                    // @ts-ignore
                    ref={frame}
                    raycast={() => null}
                    scale={[0.9, 0.93, 0.9]}
                    position={[0, 0, 0.2]}
                >
                    <boxGeometry />
                    <meshBasicMaterial toneMapped={false} fog={false} />
                </mesh>
                <Image
                    raycast={() => null}
                    // @ts-ignore
                    ref={image}
                    position={[0, 0, 0.7]}
                    url={url}
                />
            </mesh>
            <Text maxWidth={0.1} anchorX="left" anchorY="top" position={[0.55, GOLDENRATIO, 0]} fontSize={0.025}>
                {name.split('-').join(' ')}
            </Text>
        </group>
    );
}

export default ThreeCover;

==> three-cover-1.0.6.tgz: package/src/index.tsx <==
import React, { useEffect, useRef, useState } from 'react';
import { Canvas, useFrame } from '@react-three/fiber';
import { useCursor, MeshReflectorMaterial, Image, Text, Environment } from '@react-three/drei';
import { useRoute, useLocation } from 'wouter';
import getUuid from 'uuid-by-string';
import THREE, { Color } from 'three';

const GOLDENRATIO = 1.61803398875;

const ThreeCover = (images: Array<any>) => {
    return (
        // @ts-ignore
        <Canvas gl={{ alpha: false }} dpr={[1, 1.5]} camera={{ fov: 70, position: [0, 2, 15] }}>
            <color attach="background" args={['#191920']} />
            <fog attach="fog" args={['#191920', 0, 15]} />
            <Environment preset="city" />
            <group position={[0, -0.5, 0]}>
                {
                    // @ts-ignore
                    <Frames images={images} />
                }
                <mesh rotation={[-Math.PI / 2, 0, 0]} position={[0, 0, 0]}>
                    <planeGeometry args={[50, 50]} />
                    {
                        // @ts-ignore
                        <MeshReflectorMaterial
                            blur={[300, 100]}
                            resolution={2048}
                            mixBlur={1}
                            mixStrength={40}
                            roughness={1}
                            depthScale={1.2}
                            minDepthThreshold={0.4}
                            maxDepthThreshold={1.4}
                            color="#050505"
                            metalness={0.5}
                        />
                    }
                </mesh>
            </group>
        </Canvas>
    );
};

function Frames(images: Array<any>, q = new THREE.Quaternion(), p = new THREE.Vector3()) {
    const ref = useRef();
    const clicked = useRef();
    const [, params] = useRoute('/item/:id');
    const [, setLocation] = useLocation();
    useEffect(() => {
        // @ts-ignore
        clicked.current = ref.current.getObjectByName(params?.id);
        if (clicked.current) {
            // @ts-ignore
            clicked.current.parent.updateWorldMatrix(true, true);
            // @ts-ignore
            clicked.current.parent.localToWorld(p.set(0, GOLDENRATIO / 2, 1.25));
            // @ts-ignore
            clicked.current.parent.getWorldQuaternion(q);
        } else {
            p.set(0, 0, 5.5);
            q.identity();
        }
    });
    useFrame((state) => {
        state.camera.position.lerp(p, 0.025);
        state.camera.quaternion.slerp(q, 0.025);
    });

    return (
        <group
            // @ts-ignore
            ref={ref}
            onClick={(e) => (
                e.stopPropagation(), setLocation(clicked.current === e.object ? '/' : '/item/' + e.object.name)
            )}
            onPointerMissed={() => setLocation('/')}
        >
            <Frame key={images[0]?.url} {...images[0]} />
        </group>
    );
}

function Frame(url: string, c: Color = new THREE.Color(), ...props: any) {
    const [hovered, hover] = useState(false);
    const [rnd] = useState(() => Math.random());
    const image = useRef();
    const frame = useRef();
    const name = getUuid(url.toString());
    useCursor(hovered);
    useFrame((state) => {
        // @ts-ignore
        image.current.material.zoom = 2 + Math.sin(rnd * 10000 + state.clock.elapsedTime / 3) / 2;
        // @ts-ignore
        image.current.scale.x = THREE.MathUtils.lerp(
            // @ts-ignore
            image.current.scale.x,
            0.85 * (hovered ? 0.85 : 1),
            0.1,
        );
        // @ts-ignore
        image.current.scale.y = THREE.MathUtils.lerp(
            // @ts-ignore
            image.current.scale.y,
            0.9 * (hovered ? 0.905 : 1),
            0.1,
        );
        // @ts-ignore
        frame.current.material.color.lerp(c.set(hovered ? 'orange' : 'white'), 0.1);
    });

    return (
        <group {...props}>
            <mesh
                name={name}
                onPointerOver={(e) => (e.stopPropagation(), hover(true))}
                onPointerOut={() => hover(false)}
                scale={[1, GOLDENRATIO, 0.05]}
                position={[0, GOLDENRATIO / 2, 0]}
            >
                <boxGeometry />
                <meshStandardMaterial
                    color="#151515"
                    metalness={0.5}
                    roughness={0.5}
                    envMapIntensity={2}
                />
                <mesh
                    // @ts-ignore
                    ref={frame}
                    raycast={() => null}
                    scale={[0.9, 0.93, 0.9]}
                    position={[0, 0, 0.2]}
                >
                    <boxGeometry />
                    <meshBasicMaterial toneMapped={false} fog={false} />
                </mesh>
                <Image
                    raycast={() => null}
                    // @ts-ignore
                    ref={image}
                    position={[0, 0, 0.7]}
                    url={url}
                />
            </mesh>
            <Text maxWidth={0.1} anchorX="left" anchorY="top" position={[0.55, GOLDENRATIO, 0]} fontSize={0.025}>
                {name.split('-').join(' ')}
            </Text>
        </group>
    );
}

export default ThreeCover;
